
global path "your path", clear

net install http://www.stata.com/users/kcrow/tab2xl, replace
ssc install psmatch2
ssc install estout
set varabbrev on

************************************
**Table 1. Sample Characterization**
************************************
local desc_variables age gender ed_1 ed_2 fam_members income ///
 dworking dinternet  ///
trust_gov dwhatsapp instagram_facebook ///
SCR_caract_8_twitter SCR_caract_8_correo sdi_

estpost sum  `desc_variables' 
estout using "$path\Outputs\Tab1.xls", cells("count mean sd min max") label replace  

*erase "$path\Outputs\Table1.xls"

************************************
**Table 2. Sample Comparability**
************************************
*** GEIH vs. ETPV vs. VenRePS
use"$path\DataComparison", clear

local outcomes age sex years_education income health_reg__1 health_reg__2 health_reg__3 unemployed
 
estpost sum `outcomes' if sample_1==1
eststo ci_a_1
estpost sum `outcomes' if sample_2==1
eststo ci_a_2
estpost sum `outcomes' if sample_3==1
eststo ci_a_3

estpost ttest `outcomes', by(geih)  
eststo diff1

estpost ttest `outcomes', by(PEP)  
eststo diff2
	 
local row1 "mean(fmt(%9.3f) pat(1 1 1 0 0)) p(fmt(%9.3f) pat(0 0 0 1 1))"
local row2 "sd(fmt(%9.3f) par pattern(1 1 1 0 0))"
estout ci_a_1 ci_a_2 ci_a_3 diff1 diff2 ///
 using "$path\Outputs\Tab2.xls", replace  label      ///
mlabels("ETPV" "GEIH" "PEP"  ///
 "(ETPV)-(GEIH)" "(ETPV)-(PEP)")   ///
cells("`row1'" "`row2'") collabels(none)  ///
stats(N, fmt(%9.0fc)  labels("Observations"))                  ///
posthead(`post') pref(`post')


************************************
**Table 3. Successful Covariate*****
********by Treatment Type***********
************************************

use"$path\DataETPV", clear

local outcomes age gender ed_1 ed_2 fam_members sin_income ///
activity__1 ///
std_trust_gov internet_2 w_1 instagram_facebook ///
SCR_caract_8_twitter SCR_caract_8_correo sdi
 
estpost sum `outcomes' if treatment==0 
eststo ci_a_1
estpost sum `outcomes' if treatment==1
eststo ci_a_2
estpost sum `outcomes' if treatment==2
eststo ci_a_3
estpost sum `outcomes' if treatment==3
eststo ci_a_4
estpost sum `outcomes' if treatment_general==1
eststo ci_a_5


estpost ttest `outcomes' if treatment==0 | treatment==1, by(treatment)  
eststo diff1

estpost ttest `outcomes' if treatment==0 | treatment==2, by(treatment)  
eststo diff2

estpost ttest `outcomes' if treatment==0 | treatment==3, by(treatment)  
eststo diff3

estpost ttest `outcomes', by(treatment_general)  
eststo diff4
	 
local row1 "mean(fmt(%9.3f) pat(1 1 1 1 1 0 0 0 0)) p(fmt(%9.3f) pat(0 0 0 0 1 1 1 1))"
local row2 "sd(fmt(%9.3f) par pattern(1 1 1 1 1 0 0 0))"
estout ci_a_1 ci_a_2 ci_a_3 ci_a_4 ci_a_5 diff1 diff2 diff3 diff4 ///
 using "$path\Outputs\Tab3.xls", replace  label      ///
mlabels("Control" "Information Video" "Trust Video" "Step-by-Step Video" ///
"General Video" "(1)-(2)" "(1)-(3)" "(1)-(4)" "(0)-(4)")   ///
cells("`row1'" "`row2'") collabels(none)  ///
stats(N, fmt(%9.0fc)  labels("Observations"))                  ///
posthead(`post') pref(`post')


*************************************************************************
********Table 4: Characterizing Attrition *************
*******Attrition[=1 if individual never responded to IWS] *********
*******************************************************************
g attrited_all=0
replace attrited_all=1 if F0attrited==1 & F1attrited==1 & F2attrited==1 & F3attrited==1 

la var attrited_all "Attrited (Never Responded)"

global controls age gender ed_1 ed_2 fam_members  sin_income ///
 dworking std_trust_gov dinternet  ///
dwhatsapp instagram_facebook SCR_caract_8_twitter SCR_caract_8_correo sdi

foreach var of varlist attrited_all   {
reg `var' $controls
sum `var'
local av_control=r(mean)
outreg2 using "$path\Outputs\Tab4.xls", label addstat("Av. Control", `av_control') append  bdec(3) sdec(3) rdec(3)  
}


****************************************************************
********Figure 4. Attrition Rate by Type of Treatment *********
****************************************************************
preserve
collapse (mean) F0attrited_tot F1attrited_tot F2attrited_tot F3attrited_tot F0attrited_sample F1attrited_sample F2attrited_sample F3attrited_sample ///
F0follow_sample F1follow_sample F2follow_sample F3follow_sample F0_sample F1_sample F2_sample F3_sample, by(treatment)

ren F0_sample sample1
ren F1_sample sample2
ren F2_sample sample3
ren F3_sample sample4

ren F0attrited_tot attrited_tot1
ren F1attrited_tot attrited_tot2
ren F2attrited_tot attrited_tot3
ren F3attrited_tot attrited_tot4

ren F0attrited_sample attrited1
ren F1attrited_sample attrited2
ren F2attrited_sample attrited3
ren F3attrited_sample attrited4

ren F0follow_sample follow1
ren F1follow_sample follow2
ren F2follow_sample follow3
ren F3follow_sample follow4

g id=_n
reshape long attrited follow attrited_tot sample, i(id) j(contact) 

replace attrited=attrited*100
replace follow=follow*100

g contact_string="First" if contact==1
replace contact_string="Second" if contact==2
replace contact_string="Third" if contact==3
replace contact_string="Fourth" if contact==4

gen contactp2 = (3*_n)-1 +_n-1
gen contact2=contactp2+1
gen contact3=contact2+1
labmask contact2, values(contact_string)
labmask contact3, values(contact_string)

format attrited %9.2f
format sample %15.0fc

***General***
collapse(sum) attrited_tot sample, by (contact contact_string)
g attrited=(attrited_tot/sample)*100

gen contactp2 = (3*_n)-1 +_n-1
gen contact2=contactp2+1
gen contact3=contact2+1
labmask contact2, values(contact_string)
labmask contact3, values(contact_string)

format attrited %9.2f
format sample %15.0fc

***Panel A. Full Sample
twoway bar attrited_tot  contactp2, ///
mlabel(attrited_tot) mlabcolor(black) mlabsize(*.8) ///
 fcolor(olive) fintensity(20) lcolor(olive) yaxis(2) ///
ylabel(0(100)500, axis(2) labsize(*.8)) ||  ///
bar sample contact2, mlabel(sample) mlabcolor(black) mlabsize(*.8) ///
 fcolor(navy) fintensity(20) lcolor(navy) yaxis(2) ///
ylabel(0(200)1400, axis(2) labsize(*.8)) || ///
bar attrited contact3, mlabel(attrited) mlabcolor(black) mlabsize(*.8) ///
color(maroon) fintensity(20) yaxis(1) /// 
ytitle("Non-response Individuals (% Contacted Individuals)", ///
 color(black) axis(1) size(*.7))  ///
ylabel(30(10)70, axis(1) labsize(*.8) nogrid)  ysc(titlegap(2)) graphregion(fcolor(white)) ///
ytitle(" "  "Number of Individuals", color(black) axis(2) size(*.7)) ///
legend(order( 1 "Non-response individuals"  2 "Contacted individuals" 3 "Attrition rate" ) ///
 lwidth(black)  rows(2) size(*.7) ///
pos(6)) xtitle("Contact", size(*.9)) xlabel(4 8 12 16,  valuelabel labsize(*.6)) ///
plotregion(lcolor(none) ilcolor(none) style(none)) bgcolor(white)  graphregion(style(none) color(gs16))
graph export "$path\Outputs\Fig4a.pdf", replace
restore

**** Panel B. Contacted Four Times
preserve
cap drop  contacts4th
g contacts4th=0
replace contacts4th=1 if F3_final_survey_status!=".a"
keep if contacts4th==1

replace F1attrited=1 if F0attrited==1 
replace F2attrited=1 if F1attrited==1 
replace F3attrited=1 if F2attrited==1 

egen sample2=total(id)

foreach s in F0 F1 F2 F3  {
egen `s'attrited_tot2=total(id) if `s'attrited==1
}

collapse (mean) sample2 F0attrited_tot2 F1attrited_tot2 F2attrited_tot2 F3attrited_tot2 

ren F0attrited_tot2 attrited_tot1
ren F1attrited_tot2 attrited_tot2
ren F2attrited_tot2 attrited_tot3
ren F3attrited_tot2 attrited_tot4

g id=_n
reshape long attrited_tot , i(id) j(contact) 

g attrited=attrited_tot/sample2*100

g contact_string="First" if contact==1
replace contact_string="Second" if contact==2
replace contact_string="Third" if contact==3
replace contact_string="Fourth" if contact==4

gen contactp2 = (3*_n)-1 +_n-1
gen contact2=contactp2+1
gen contact3=contact2+1
labmask contact2, values(contact_string)
labmask contact3, values(contact_string)

format attrited %9.2f
format sample2 %15.0fc

**********************General Video*****************
twoway bar attrited_tot  contactp2, ///
mlabel(attrited_tot) mlabcolor(black) mlabsize(*.8) ///
 fcolor(olive) fintensity(20) lcolor(olive) yaxis(2) ///
ylabel(0(100)500, axis(2) labsize(*.8)) ||  ///
bar sample contact2, mlabel(sample) mlabcolor(black) mlabsize(*.8) ///
 fcolor(navy) fintensity(20) lcolor(navy) yaxis(2) ///
ylabel(0(200)1000, axis(2) labsize(*.8)) || ///
bar attrited contact3, mlabel(attrited) mlabcolor(black) mlabsize(*.8) ///
color(maroon) fintensity(20) yaxis(1) /// 
ytitle("Non-response Individuals (% Contacted Individuals)", ///
 color(black) axis(1) size(*.7))  ///
ylabel(50(10)100, axis(1) labsize(*.8) nogrid)  ysc(titlegap(2)) graphregion(fcolor(white)) ///
ytitle(" "  "Number of Individuals", color(black) axis(2) size(*.7)) ///
legend(order( 1 "Non-response individuals"  2 "Contacted individuals" 3 "Attrition rate" ) ///
 lwidth(black)  rows(2) size(*.7) ///
pos(6)) xtitle("Contact", size(*.9)) xlabel(4 8 12 16,  valuelabel labsize(*.6)) ///
plotregion(lcolor(none) ilcolor(none) style(none)) bgcolor(white)  graphregion(style(none) color(gs16))
graph export "$path\Outputs\Fig4b.pdf", replace
restore

*************************************************************************
***** Table 5. Distribution of Possible Contact Combinations ***********
***** Individuals Contacted Four Times ************** ************** 
*************************************************************************
preserve
keep if contacts4th==1
foreach var of varlist F0attrited F1attrited F2attrited F3attrited {
g N`var'=1-`var'	
}
	
egen group  = group(NF0attrited NF1attrited NF2attrited NF3attrited), label
*** Panel A. Possible Contact Cases
tab group, generate(gr_)

tab2xl group using "$path\Outputs\Tab5a.xls", row(1) col(1) replace


*** Panel B. Successfully Reached Combinations	
g group_contact=1 if gr_1==1
replace group_contact=2 if gr_2==1| gr_3==1 | gr_5==1 | gr_9==1
replace group_contact=3 if gr_4==1| gr_7==1 | gr_13==1 
replace group_contact=4 if gr_6==1 | gr_10==1 | gr_11==1 
replace group_contact=5 if gr_8==1| gr_15==1
replace group_contact=6 if gr_12==1 | gr_14==1 
replace group_contact=7 if gr_16==1 

la def group_contact 1 "Never" 2 "One Time" ///
3 "Two Consecutive Times" 4 "Two Non-Consecutive Times" ///
5 "Three Consecutive Times" 6 "Three Non-Consecutive Times" ///
7 "Always"	
la val 	group_contact group_contact

tab2xl group_contact using "$path\Outputs\Tab5b.xls", row(1) col(1) replace

restore

**************************************************************
******** Figure 5. Video Play Rates by Treatment Arm**********
**************************************************************	
preserve
keep video1 INT_dummy_video_completed video2 ///
 F1_dummy_video_completed video3 F2_dummy_video_completed video4 /// 
 F3_dummy_video_completed  INT_perc_completed1 INT_perc_completed2 INT_perc_completed3 F1_perc_completed1 /// 
 F1_perc_completed2 F1_perc_completed3 F2_perc_completed1 F2_perc_completed2 F2_perc_completed3 /// 
 F3_perc_completed1 F3_perc_completed2 F3_perc_completed3 /// 
INT_maxenplay1 INT_maxenplay2 INT_maxenplay3 INT_max_total F1_maxenplay1 F1_maxenplay2 F1_maxenplay3 /// 
 F1_max_total F2_maxenplay1 F2_maxenplay2 F2_maxenplay3 F2_max_total F3_maxenplay1 F3_maxenplay2 /// 
 F3_maxenplay3 F3_max_total  treatment
 
ren INT_perc_completed1  perc_video_first1
ren INT_perc_completed2  perc_video_second1
ren INT_perc_completed3  perc_video_third1

ren F1_perc_completed1 perc_video_first2
ren F1_perc_completed2 perc_video_second2
ren F1_perc_completed3 perc_video_third2

ren F2_perc_completed1 perc_video_first3
ren F2_perc_completed2 perc_video_second3
ren F2_perc_completed3 perc_video_third3

ren F3_perc_completed1 perc_video_first4
ren F3_perc_completed2 perc_video_second4
ren F3_perc_completed3 perc_video_third4

g id=_n
reshape long video INT_perc_completed perc_video_first perc_video_second perc_video_third , i(id) j(contact) 

drop if treatment==0

replace video=0 if vide==.r

collapse (mean) video perc_video_first perc_video_second perc_video_third , by(contact treatment)

la def contact 1 "First" 2 "Second" 3 "Third" 4 "Fourth"
la val contact contact
replace video=video*100
drop if video==.

graph bar video perc_video_first , over(contact, lab(angle(45))) over(treatment) ///
blabel(bar, position(outside) size(vsmall) format(%9.1f) color(black)) ///
graphregion(color(white))  ///
ytitle(Percentage (%), color(black) size(medium)) /// 
legend( label(1 "Played the Video") label(2 "Play Time (%)") pos(6) row(1)) ///
bargap(-5) yl( , nogrid) ///
b1title(Contact) ///
bar(1, color(navy) fintensity(20)) bar(2, color(sienna) fintensity(20)) ///
plotregion(lcolor(none) ilcolor(none) style(none)) bgcolor(white)  graphregion(style(none) color(gs16))
graph export "$path\Outputs\Fig5.pdf", replace
restore

***************************************************
******** Table 6. Intervention Effects on************
**** PPT Take-up Rates (Responses from Last Contact)
********** ********************************************
use"$path\DataETPV",clear	

*Panel A: General Effect
foreach var of varlist requested_ppt start_rumv intend_rumv {
reg `var' treatment_general if sample==1
outreg2 using "$path\Outputs\Tab6a.xls", bdec(3) label append
	}	
	
*Panel B: Disaggregated Treatment Effect
foreach var of varlist requested_ppt start_rumv intend_rumv {
		reg `var' treatment_1 treatment_2 treatment_3
sum `var' if treatment_0==1
local av_control=r(mean)
outreg2 using "$path\Outputs\Tab6b.xls",  nocons label  bdec(3) addstat("Av. Control", `av_control')
	}	

***************************************************
******** Table 7. Video Play Time Percentage 
*********Distribution Contact)    **************
********** ********************************************
egen video_time=rowmax(INT_perc_completed1 INT_perc_completed2 INT_perc_completed3 F1_perc_completed1 F1_perc_completed2 F1_perc_completed3 F2_perc_completed1 F2_perc_completed2 F2_perc_completed3 F3_perc_completed1 F3_perc_completed2 F3_perc_completed3)	
replace video_time=0 if video_time==.r | video_time==. |(video_time==.a & treatment_general==1)
	
g video_time_group=1 if video_time==0 
replace video_time_group=2 if video_time>0 & video_time<10
replace video_time_group=3 if video_time>10 & video_time<20
replace video_time_group=4 if video_time>20 & video_time<30
replace video_time_group=5 if video_time>30 & video_time<40
replace video_time_group=6 if video_time>40 & video_time<50
replace video_time_group=7 if video_time>50 & video_time<60
replace video_time_group=8 if video_time>60 & video_time<70
replace video_time_group=9 if video_time>70 & video_time<80
replace video_time_group=10 if video_time>80 & video_time<=90
replace video_time_group=11 if video_time>90 & video_time<=99
replace video_time_group=12 if video_time>99 & video_time<105

tab2xl video_time_group if treatment_general==1 & sample==1 & requested_ppt!=. using "$path\Outputs\Tab7.xls", row(1) col(1) 


***************************************************
******** Table 8. Who Played the Video? **************
********** ********************************************
	
g vtime=1 if video_time>0
replace vtime=0 if video_time==0
replace vtime=. if treatment_general==0

local outcomes  age gender ed_1 ed_2 fam_members minors sin_income ///
health_reg__1 health_reg__3  activity__1 activity__2 activity__3 activity__4 ///
std_trust_gov internet_2 internet_3  w_1 w_2 instagram_facebook ///
SCR_caract_8_twitter SCR_caract_8_correo sdi

estpost sum `outcomes' if vtime==1 & requested_ppt!=.
eststo ci_a_1

estpost sum `outcomes' if vtime==0 & requested_ppt!=.
eststo ci_a_2

estpost ttest `outcomes' if requested_ppt!=., by(vtime)  
eststo diff1

estadd local diff2 `= round(r(mu_1) - r(mu_2), .01))'

local row1 "mean(fmt(%9.3f) pat(1 1 0)) p(fmt(%9.3f) pat(0 0 1))"
local row2 "sd(fmt(%9.3f) par pattern(1 1 0 ))"

estout ci_a_2 ci_a_1 diff1 using "$path\Outputs\Tab8.xls", replace  label ///
cells("mean(pattern(1 1 0) fmt(3)) b(pattern(0 0 1) fmt(3)) p(fmt(%9.3f) pat(0 0 1 1))" "sd(pattern(1 1 0) par)" )  ///
mlabels("Did not Played Video" "Played Video" "Difference" "P-Value")   ///
collabels(none)  ///
stats(N, fmt(%9.0fc)  labels("Observations"))                  ///
posthead(`post') pref(`post')


***************************************************
******** Table 9. Intervention Effects on *********
 ********* PPT Take-up Rates (Responses from Last Contact)
********* Propensity Score Matching **************
********** ********************************************

*****Panel A. Propensity Score Matching - People who did not played the video
g vtime_0=1 if vtime==0
replace vtime_0=0 if treatment_general==0

probit treatment_general age gender ed_1 ed_2 fam_members minors sin_income ///
health_reg__1 health_reg__3  activity__1 activity__2 activity__3 activity__4 ///
std_trust_gov internet_2 internet_3  w_1 w_2 instagram_facebook ///
SCR_caract_8_twitter SCR_caract_8_correo sdi if vtime_0!=.

predict pscore1, pr
sum pscore1

foreach y in requested_ppt start_rumv intend_rumv{
psmatch2 treatment_general if vtime_0!=.,  pscore(pscore1) outcome(`y') common 
reg `y' treatment_general if _support==1 &  vtime_0!=.
sum `y' if _support==1 &  vtime_0==0
local av_control=r(mean)
outreg2 using "$path\Outputs\Tab9a.xls", label addstat("Av. Control", `av_control') append  bdec(3) sdec(3) rdec(3)
}


****Panel B. Propensity Score Matching - People who played the video

g vtime_1=1 if vtime==1
replace vtime_1=0 if treatment_general==0

probit treatment_general age gender ed_1 ed_2 fam_members minors sin_income ///
health_reg__1 health_reg__3  activity__1 activity__2 activity__3 activity__4 ///
std_trust_gov internet_2 internet_3  w_1 w_2 instagram_facebook ///
SCR_caract_8_twitter SCR_caract_8_correo sdi if vtime_1!=.

cap drop pscore1
predict pscore1, pr
sum pscore1

foreach y in requested_ppt start_rumv intend_rumv{
psmatch2 treatment_general if vtime_1!=.,  pscore(pscore1) outcome(`y') common 
reg `y' treatment_general if _support==1 &  vtime_1!=.
sum `y' if _support==1 & vtime_1==0
local av_control2=r(mean)
outreg2 using "$path\Outputs\Tab9b.xls",  label addstat("Av. Control", `av_control2') append  bdec(3) sdec(3) rdec(3)
}

drop _treated pscore1

**** Table 10. Heterogeneous Effects on PPT Take-up Rates by Video Reproduction

*Panel A: General Effect - ITT

*Did not played the video
foreach var of varlist requested_ppt start_rumv intend_rumv {
		reg `var' treatment_general if vtime_0!=.
		sum `var' if treatment_0==1 &  vtime_0!=.
		local av_control=r(mean)
outreg2 using "$path\Outputs\Tab10a.xls", bdec(3) label append addstat("Av. Control", `av_control')
	}

*Played the video	
foreach var of varlist requested_ppt start_rumv intend_rumv {
		reg `var' treatment_general if vtime_1!=. 
		sum `var' if treatment_0==1 &  vtime_1!=. 
		local av_control=r(mean)
outreg2 using "$path\Outputs\Tab10a.xls", bdec(3) label append addstat("Av. Control", `av_control')
	}	
	

*Panel B: Dissaggregated Effect - ITT

*Did not played the video	
foreach var of varlist requested_ppt start_rumv intend_rumv {
reg `var' treatment_1 treatment_2 treatment_3 if vtime_0!=.
outreg2 using "$path\Outputs\Tab10b.xls",  nocons  bdec(3) 
	}	
	
*Played the video	
foreach var of varlist requested_ppt start_rumv intend_rumv {
reg `var' treatment_1 treatment_2 treatment_3 if vtime_1!=.
outreg2 using "$path\Outputs\Tab10b.xls",  nocons  bdec(3) 
	}	


*************************************************************************
****Table 11. Heterogeneous Effects on PPT Take-up Rates by Video Reproduction*******************************************************************
g dvideo=0 if video_time==0 | treatment_general==0
replace dvideo=1 if (video_time>0.008 & treatment_general==1)

g treatvt1=treatment_general*dvideo

foreach var of varlist requested_ppt start_rumv intend_rumv {
reg `var' treatvt1 treatment_general dvideo 
lincom treatvt1+treatment_general
local coef=r(estimate)
local se=r(se)
local t `=`coef'/`se''
sum `var' if treatment_0==1 &  dvideo==0
local av_control=r(mean)
outreg2 using "$path\Outputs\Tab11.xls", less(0) nocons  bdec(3) addstat("estimate", `coef', "standard error", `se', "t statistic", `t',"Av. Control", `av_control')
	}

************************************************************	
***Table B.1. Intervention Effects on PPT Take-up Rates******
**********(Responses from First Contact)******************
*********************************************************
*Panel A: General Effect
foreach var of varlist requested_ppt0 start_rumv0 intend_rumv0 {
		reg `var' treatment_general
outreg2 using "$path\Outputs\TabB1a.xls", bdec(3) label append
	}
	
*Panel B: Disaggregated Treatment Effect
foreach var of varlist requested_ppt0 start_rumv0 intend_rumv0 {
reg `var' treatment_1 treatment_2 treatment_3
sum `var' if treatment_0==1
local av_control=r(mean)
outreg2 using "$path\Outputs\TabB1b.xls",  nocons  bdec(3) addstat("Av. Control", `av_control')
	}	

**********************************************************
***************Appendix C: More Attrition ****************
**********************************************************

*****************************************************************
********Table C.1: Distribution of Attrition by Treatment Status***
**********and Different Definitions of Attrition ****************
*****************************************************************

g attrited_all=0
replace attrited_all=1 if F0attrited==1 & F1attrited==1 & F2attrited==1 & F3attrited==1 

la var attrited_all "Attrited (Never Responded)"

g lost_follow_up=0  
replace lost_follow_up=1 if F1attrited==0 & requested_ppt==0
replace lost_follow_up=1 if F2attrited==0 & requested_ppt==0
replace lost_follow_up=1 if F3attrited==0 & requested_ppt==0

g lost_follow_up_complete=0
replace lost_follow_up_complete=1 if attrited_all==1 | lost_follow_up==1
la var lost_follow_up "Lost-to-Follow-Up"
la var lost_follow_up_complete "Lost-to-Follow-Up and Attrited All Contacts"

local outcomes attrited_all lost_follow_up lost_follow_up_complete

estpost sum `outcomes' 
eststo ci_a_0
estpost sum `outcomes' if treatment==0 
eststo ci_a_1
estpost sum `outcomes' if treatment==1
eststo ci_a_2
estpost sum `outcomes' if treatment==2
eststo ci_a_3
estpost sum `outcomes' if treatment==3
eststo ci_a_4
estpost sum `outcomes' if treatment_general==1
eststo ci_a_5

	 
local row1 "mean(fmt(%9.3f) pat(1 1 1 1 1 1))"
estout ci_a_0 ci_a_1 ci_a_2 ci_a_3 ci_a_4 ci_a_5  ///
 using "$path\Outputs\TabC1.xls", replace  label      ///
mlabels( "All Sample" "Control" "Awareness Video" "Trust Video" "Step-by-Step Video" "Any Video")   ///
cells("`row1'") collabels(none)  ///
stats(N, fmt(%9.0fc)  labels("Observations")) ///
posthead(`post') pref(`post')

***********************************************************
***************Table C.2. Characterizing Attrition ********
***********************************************************
foreach var of varlist age gender ed_1 ed_2 fam_members sin_income ///
 dworking dinternet  ///
std_trust_gov dwhatsapp instagram_facebook ///
SCR_caract_8_twitter SCR_caract_8_correo sdi  {
g `var't=`var'*treatment_general
}

global controls  age gender ed_1 ed_2 fam_members sin_income ///
 dworking dinternet  ///
std_trust_gov dwhatsapp instagram_facebook ///
SCR_caract_8_twitter SCR_caract_8_correo sdi ///
aget gendert ed_1t ed_2t fam_memberst sin_incomet dworkingt dinternett ///
 std_trust_govt dwhatsappt instagram_facebookt SCR_caract_8_twittert SCR_caract_8_correot sdit ///
treatment_general


foreach var of varlist attrited_all lost_follow_up lost_follow_up_complete {
reg `var' $controls
sum `var'
local av_control=r(mean)
outreg2 using "$path\Outputs\TabC2.xls", label addstat("Av. Control", `av_control') append  bdec(3) sdec(3) rdec(3)  
}

***********************************************
*****************Q-Vaules*************************
*************************************************
	
*To generate the FDR q-values for each table, please change the line 10 with the table required,
* it produces the q-values corresponding for each of the tables "Tab6A, Tab9A, Tab9B, TabB1"

use"$path\p-values", clear
keep if sample=="TabB1"
**** Ejemplo para el método conventional del RD-Robust
encode outcome, g(cod_outcome)
drop outcome 

**** Now use Michael Anderson's code for sharpened q-values
* Collect the total number of p-values tested
quietly sum pval
local totalpvals = r(N)

* Sort the p-values in ascending order and generate a variable that codes each p-value's rank

quietly gen int original_sorting_order = _n
quietly sort pval
quietly gen int rank = _n if pval~=.

* Set the initial counter to 1 

local qval = 1

* Generate the variable that will contain the BKY (2006) sharpened q-values

gen bky06_qval = 1 if pval~=.

* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  The loop ends by checking which hypotheses are rejected at q = 0.001.


while `qval' > 0 {
	* First Stage
	* Generate the adjusted first stage q level we are testing: q' = q/1+q
	local qval_adj = `qval'/(1+`qval')
	* Generate value q'*r/M
	gen fdr_temp1 = `qval_adj'*rank/`totalpvals'
	* Generate binary variable checking condition p(r) <= q'*r/M
	gen reject_temp1 = (fdr_temp1>=pval) if pval~=.
	* Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank1 = reject_temp1*rank
	* Record the rank of the largest p-value that meets above condition
	egen total_rejected1 = max(reject_rank1)

	* Second Stage
	* Generate the second stage q level that accounts for hypotheses rejected in first stage: q_2st = q'*(M/m0)
	local qval_2st = `qval_adj'*(`totalpvals'/(`totalpvals'-total_rejected1[1]))
	* Generate value q_2st*r/M
	gen fdr_temp2 = `qval_2st'*rank/`totalpvals'
	* Generate binary variable checking condition p(r) <= q_2st*r/M
	gen reject_temp2 = (fdr_temp2>=pval) if pval~=.
	* Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank2 = reject_temp2*rank
	* Record the rank of the largest p-value that meets above condition
	egen total_rejected2 = max(reject_rank2)

	* A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition
	replace bky06_qval = `qval' if rank <= total_rejected2 & rank~=.
	* Reduce q by 0.001 and repeat loop
	drop fdr_temp* reject_temp* reject_rank* total_rejected*
	local qval = `qval' - .001
}
	

quietly sort original_sorting_order
br





