cd"C:\Users\mjurb\CEGA Dropbox\Maria Jose Urbina Florez\ETPV\4.RepMaterials"
use"data_IPA.dta", clear

*****************************************
***********Constructing Variables *******
*****************************************

rename SCR_s2 age
lab var age "Age"

gen gender = SCR_caract_1
recode gender (2=0)(4=.)
lab var gender "Male [=1]"
lab def male 1"Male" 0"Female"
lab values gender male

rename SCR_caract_4 minors
lab var minors "Number of minors in charge"
rename SCR_caract_3 fam_members
lab var fam_members "Number of household members"
rename SCR_caract_2_level years_education
lab var years_education "Years of education"

rename SCR_caract_6 income
lab var income "Personal Income"


*| Recode outlier data
* Participant (id:1912-1157--5666) report an income for 1'014.000.000 (typo) 
recode income (1014000000=.)
rename SCR_caract_7 house_income
lab var house_income "Household Income"


foreach var of varlist  income house_income {
replace `var'=0 if `var'==.	
}

*** Sin Hyperbolic
foreach i in  income house_income {
g sin_`i' = log(`i'+sqrt((`i')^2+1))
}

la var sin_income "Personal Income (Sin*)"

*| 
rename SCR_caract_2 leved
lab var leved "Level of education"

*| Other control variables
rename SCR_s6 document_valid
lab var document_valid "Documentation to apply to ETPV [=1]"
recode document_valid (2=0)
lab def afirmation 1"Yes" 0"No"
lab val document_valid afirmation

rename SCR_caract_9 internet
lab var internet "Hours of internet"
rename SCR_s10 whatsapp
lab var whatsapp "Own whatsapp"
rename SCR_s13 trust_gov
lab var trust_gov "Trust in Colombian Government"
rename SCR_s14 trust_mig
lab var trust_mig "Trust in Migration Colombia"

rename SCR_s15 knowETPV
lab var knowETPV "Knowledge about ETPV [=1]"
recode knowETPV (2=0)
lab val knowETPV afirmation

*| Social-desirability index
rename SCR_s19 Q1_STD
lab var Q1_STD "Difficult to work with out motivation"
rename SCR_s20 Q2_STD
lab var Q2_STD "Jeleous of the fortune of others"
rename SCR_s21 Q3_STD
lab var Q3_STD "I admit when I make a mistake"
rename SCR_s22 Q4_STD
lab var Q4_STD "I'm always kind"

global SDI_vars Q1_STD Q2_STD Q3_STD Q4_STD

*=================
* 4 - scale Index
*=================

*| Participants that have answer all 4 SD questions.
gen full_SDI = 1 
forvalues i=1/4{
	replace full_SDI = . if Q`i'==.a | Q`i'==.d | Q`i'==.r
}

gen SD1 = 1 if full_SDI==1 & Q1_STD==2
replace SD1 = 0 if full_SDI==1 & Q1_STD==1

gen SD2 = 1 if full_SDI==1 & Q2_STD==2
replace SD2 = 0 if full_SDI==1 & Q2_STD==1

gen SD3 = 1 if full_SDI==1 & Q3_STD==1
replace SD3 = 0 if full_SDI==1 & Q3_STD==2

gen SD4 = 1 if full_SDI==1 & Q4_STD==1
replace SD4 = 0 if full_SDI==1 & Q4_STD==2

*INDEX
egen sdi_ = rowtotal(SD1 SD2 SD3 SD4)
egen sdi=std(sdi_)
label var sdi_ "Social desirability index"
label var sdi "Social desirability index (SD)"

************************
* Education levels
************************
gen levofed = .
* Group of None/Preschool/Primary education
replace levofed = 1 if leved ==1 | leved ==2 | leved ==3
*Group of General School/Diversified School
replace levofed = 2 if leved == 4 | leved==5 
*Group of Tech.School/Certification Course/ University/Graduate School
replace levofed = 3 if leved > 5

tab levofed, g(ed_)
la var ed_1 "Ed. Level: Primary or Less [=1]"
la var ed_2 "Ed. Level: General or diversified school [=1]"
la var ed_3 "Ed. Level: Technical school or more [=1]"

*******************
** Internet********
******************
replace internet=. if internet==.a | internet==.d | internet==.r

gen internet_access=.
* Group of None/Preschool/Primary education
replace internet_access=1 if internet==6 | internet==7 
*Group of General School/Diversified School
replace internet_access=2 if leved== 3 | leved==4 | internet==5
*Group of Tech.School/Certification Course/ University/Graduate School
replace internet_access=3 if internet==1 | internet==2 

tab internet_access, g(internet_)

la var internet_1 "Internet Access: none or less than 1 hour [=1]"
la var internet_2 "Internet Access: 1 to 4 hours [=1]"
la var internet_3 "Internet Access: All or half of the day [=1]"

g internet_reg=1 if internet_3==1
replace internet_reg=0 if internet_1==1 | internet_2==1
la var internet_reg "Internet Access: All or half of the day [=1]" 

*******************
** Quality of Internet********
******************
	clonevar 	quali_internet = SCR_caract_10
	recode 		quali_internet (1 =3) (3 = 1) 
	lab var 	quali_internet "Quality of internet"  
	lab def 	quali_internet 1 "Bad" 2 "Regular" 3 "Good" 
	lab val	 	quali_internet quali_internet
**************
***Trust******
**************
replace trust_gov=. if trust_gov==.a | trust_gov==.d | trust_gov==.r
la var trust_gov "Trust in Colombian Government (1-5)"

replace trust_mig=. if trust_mig==.a | trust_mig==.d | trust_mig==.r
la var trust_mig "Trust in Colombian Migration Agency (1-5)"


foreach var of varlist trust_gov trust_mig {
egen std_`var'=std(`var')	
}

lab var std_trust_gov "Trust in Colombian Government (SD)"
lab var std_trust_mig "Trust in Migration Colombia (SD)"

*******************
***Occupation******
*******************
	clonevar 	activity = SCR_caract_5
	recode 		activity (6 = .) //ask
	lab var 	activity "Activity spent most of time on last week"
	tab 		activity, gen(activity__)
	
	lab var 	activity__1 "Activity spent the most time: Working [=1]"
	lab var 	activity__2 "Activity spent the most time: Looking for a job [=1]"
	lab var 	activity__3 "Activity spent the most time: Studying [=1]"
	lab var 	activity__4 "Activity spent the most time: Doing house chores [=1]"
	lab var 	activity__5 "Activity (Unable to work)"
	
	
********************
***Health Regime****
********************
	clonevar 	health_reg = SCR_caract_11
	lab var 	health_reg "Health regime"
	tab 		health_reg, gen(health_reg__)
	
	lab var		health_reg__1 "Health regime: Subsidized healthcare [=1]"
	lab var		health_reg__2 "Health regime: Contributory healthcare [=1]"	
	lab var		health_reg__3 "Health regime: None [=1]"	
	
	g health=0 if health_reg==3
	replace health=1 if health_reg==1 | health_reg==2
	la var health "Subsidized or contributory healthcare system [=1]"
	
********************
***Whatsapp****
********************	

tab whatsapp, g(w_)
la var w_1 "Personal use whatsapp [=1]"
la var w_2 "Family use whatsapp [=1]"
la var w_3 "Public whatsapp [=1]"

g whatsapp_reg=1 if w_1==1 | w_2==1
replace whatsapp_reg=0 if w_3==1
la var whatsapp_reg "Personal or family whatsapp use [=1]"


g instagram_facebook=0 if SCR_caract_8_facebook!=.
replace instagram_facebook=1 if SCR_caract_8_facebook==1 | SCR_caract_8_instagram==1
la var instagram_facebook "Facebook or Instagram account [=1]"
la var SCR_caract_8_twitter "Twitter account [=1]"
la var SCR_caract_8_correo "E-mail account [=1]"
	
	
***************
* Treatments
**************
*\ Treatment variable (groups 1, 2, 3)
rename INT_grupo_tratamiento treatment
*\ Absorb Treatment variable (1=[Treatment 1, 2, 3] and 0=[Control]) 
rename INT_estado_tratamiento treatment_general


**************************
********Attrition*********
**************************

g F0_final_survey_status=INT_participants_survey  

g id=1
bys treatment: egen F0_sample=total(id)


foreach s in  F1 F2 F3 {
bys treatment: egen `s'_sample=total(id) if `s'_final_survey_status != ".a"
}

foreach s in F0  {
bys treatment: egen `s'_sc=total(id) if `s'_final_survey_status==1
}

foreach s in F1 F2 F3 {
bys treatment: egen `s'_sc=total(id) if `s'_final_survey_status=="Complete"
}

foreach s in F0 F1 F2 F3 {
bys treatment: g `s'attrited_tot= `s'_sample-`s'_sc
}


foreach s in F0 F1 F2 F3 {
bys treatment: g `s'follow_sample= `s'_sc/`s'_sample
}

foreach s in F0 F1 F2 F3 {
bys treatment: g `s'attrited_sample= 1-`s'follow_sample
}

foreach s in  F1 F2 F3 {
bys treatment: g `s'attrited=0 if 	`s'_final_survey_status=="Complete"
bys treatment: replace `s'attrited=1 if `s'_final_survey_status=="Failed delivery" | `s'_final_survey_status=="Ignored the survey" | `s'_final_survey_status=="Incomplete" | `s'_final_survey_status=="Refused"
}

foreach s in  F1 F2 F3 {
bys treatment: g `s'attrited2=0 if 	`s'_final_survey_status=="Complete" | `s'_final_survey_status=="Incomplete"
bys treatment: replace `s'attrited2=1 if `s'_final_survey_status=="Failed delivery" | `s'_final_survey_status=="Ignored the survey" | `s'_final_survey_status=="Refused"
}



bys treatment: g F0attrited=1 if F0_final_survey_status==0
bys treatment: replace F0attrited=0 if F0_final_survey_status==1


g contacts4th=0
replace contacts4th=1 if F3_final_survey_status!=".a"

replace F3attrited=0 if F3attrited==. & contacts4th==1
replace F2attrited=0 if F2attrited==. & contacts4th==1

************************

forval i =1/5 {
foreach s in  F1 F2 F3 {
replace `s'_MECHA_`i'=0 if `s'_MECHA_`i'==3
}
}


g always_attrited=1 if F0attrited==1 & F1attrited2==1 & F2attrited2==1 & F3attrited2==1 

g requested_ppt=0
replace requested_ppt=1 if INT_MECHA_2==1 | INT_MECHA_3==1 | ///
F1_MECHA_1==1 | F1_MECHA_2==1 | F1_MECHA_3==1 | ///
F2_MECHA_1==1 | F2_MECHA_2==1 | F2_MECHA_3==1 | ///
F3_MECHA_1==1 | F3_MECHA_2==1 | F3_MECHA_3==1 
replace requested_ppt=. if always_attrited==1

g start_rumv=0
replace start_rumv=1 if (INT_MECHA_4==1 | ///
F1_MECHA_4==1 |  ///
F2_MECHA_4==1 | ///
F3_MECHA_4==1) |  requested_ppt==1
replace start_rumv=. if always_attrited==1


g intend_rumv=0
replace intend_rumv=1 if (INT_MECHA_5==1 | ///
F1_MECHA_5==1 |  ///
F2_MECHA_5==1 | ///
F3_MECHA_5==1) |  start_rumv==1
replace intend_rumv=. if always_attrited==1

******Extra Clean*****
g dinternet=1 if internet>=1 & internet<=3
replace dinternet=0 if internet>3 & internet<=7

g dwhatsapp=1 if w_1==1 
replace  dwhatsapp=0 if w_3==1 |  w_2==1

g dworking=0
replace dworking=1 if activity__1==1

la var dinternet "Internet Access more than 4 hour per day  [=1]"
la var dwhatsapp "Personal use Whatsapp [=1]"
la var dworking "Activity spent the most time: Working [=1]"

foreach var of varlist dinternet health  dwhatsapp gender ed_1 ed_2 ed_3  ///
health_reg__1 health_reg__2 health_reg__3 activity__1 ///
activity__2 activity__3 activity__4  internet_1  ///
internet_2 internet_3 ///
w_1 w_2 w_3 instagram_facebook SCR_caract_8_twitter SCR_caract_8_correo  {
replace `var'=round(uniform()) if `var'==. | `var'==.r	| `var'==.a
} 


foreach var of varlist fam_members minors income sin_income ///
 house_income  std_trust_gov trust_gov  sdi {
egen m`var'=mean(`var') 
} 

foreach var of varlist fam_members minors house_income income sin_income ///
 house_income  std_trust_gov  trust_gov sdi {
replace `var'=m`var' if `var'==. | `var'==.r	| `var'==.a | `var'==.d
} 


tab treatment, g(treatment_)
ren (treatment_1 treatment_2 treatment_3 treatment_4) (treatment_0 treatment_1 treatment_2 treatment_3)
	g sample=1 if age!=. & gender!=. & ed_1!=. & ed_2!=. & fam_members!=. & sin_income!=. & ///
health!=. & dworking!=. & ///
std_trust_gov!=. & dinternet!=. & dwhatsapp!=.1 & instagram_facebook!=. & ///
SCR_caract_8_twitter!=. & SCR_caract_8_correo!=. & sdi!=.


estimates clear
foreach var of varlist dinternet health  dwhatsapp gender ed_1 ed_2 ed_3  ///
health_reg__1 health_reg__2 health_reg__3 activity__1 ///
activity__2 activity__3 activity__4  internet_1  ///
internet_2 internet_3 ///
w_1 w_2 w_3 instagram_facebook SCR_caract_8_twitter SCR_caract_8_correo  {
replace `var'=round(uniform()) if `var'==. | `var'==.r	| `var'==.a
} 

g requested_ppt0=0
replace requested_ppt0=1 if INT_MECHA_2==1 | INT_MECHA_3==1 
replace requested_ppt0=. if always_attrited==1

g start_rumv0=0
replace start_rumv0=1 if INT_MECHA_4==1 | ///
requested_ppt0==1
replace start_rumv0=. if always_attrited==1

g intend_rumv0=0
replace intend_rumv0=1 if INT_MECHA_5==1 |  start_rumv==1
replace intend_rumv0=. if always_attrited==1


ren INT_dummy_video_attempt video1
ren F1_dummy_video_attempt video2
ren F2_dummy_video_attempt video3
ren F3_dummy_video_attempt video4

g video1_90=1 if  INT_completed_attempt1==1 |  INT_completed_attempt2==1 | INT_completed_attempt3==1 
g video2_90=1 if  F1_completed_attempt1==1 |  F1_completed_attempt2==1 | F1_completed_attempt3==1 
g video3_90=1 if  F2_completed_attempt1==1 |  F2_completed_attempt2==1 | F2_completed_attempt3==1
g video4_90=1 if  F3_completed_attempt1==1 |  F3_completed_attempt2==1 | F3_completed_attempt3==1 

g video=0
replace video=1 if  video1==1 | video2==1 | video3==1 | video4==1 

g video_90=0
replace video_90=1 if  video1_90==1 | video2_90==1 | video3_90==1 | video4_90==1 


	
foreach var of varlist treatment_1 treatment_2 treatment_3 {
g video1_90`var'=1 if  INT_completed_attempt1==1 |  INT_completed_attempt2==1 | INT_completed_attempt3==1 & `var'==1
g video2_90`var'=1 if  F1_completed_attempt1==1 |  F1_completed_attempt2==1 | F1_completed_attempt3==1 & `var'==1
g video3_90`var'=1 if  F2_completed_attempt1==1 |  F2_completed_attempt2==1 | F2_completed_attempt3==1 & `var'==1
g video4_90`var'=1 if  F3_completed_attempt1==1 |  F3_completed_attempt2==1 | F3_completed_attempt3==1 & `var'==1
}

foreach var of varlist treatment_1 treatment_2 treatment_3 {
g video_90`var'=0
replace video_90`var'=1 if  video1_90`var'==1 | video2_90`var'==1 | video3_90`var'==1 | video4_90`var'==1 	
}


foreach var of varlist treatment_1 treatment_2 treatment_3 {
g video_90`var'first=0
replace video_90`var'first=1 if  video1_90`var'==1
}

g video90_first=0
replace video90_first=1 if video1_90==1

save"C:\Users\mjurb\CEGA Dropbox\Maria Jose Urbina Florez\ETPV\4.RepMaterials\DataETPV", replace

